/// <reference types="bun-types" />
import { Database, Statement as BunStatement } from 'bun:sqlite';
import { Logger } from 'drizzle-orm';
import { Query } from 'drizzle-orm/sql';
import { SQLiteSyncDialect } from '../dialect';
import { SelectFieldsOrdered } from '../operations';
import { PreparedQuery as PreparedQueryBase, PreparedQueryConfig as PreparedQueryConfigBase, SQLiteSession } from '../session';
export interface SQLiteBunSessionOptions {
    logger?: Logger;
}
declare type PreparedQueryConfig = Omit<PreparedQueryConfigBase, 'statement' | 'run'>;
declare type Statement = BunStatement<any>;
export declare class SQLiteBunSession extends SQLiteSession<'sync', void> {
    private client;
    private logger;
    constructor(client: Database, dialect: SQLiteSyncDialect, options?: SQLiteBunSessionOptions);
    exec(query: string): void;
    prepareQuery<T extends Omit<PreparedQueryConfig, 'run'>>(query: Query, fields?: SelectFieldsOrdered): PreparedQuery<T>;
}
export declare class PreparedQuery<T extends PreparedQueryConfig = PreparedQueryConfig> extends PreparedQueryBase<{
    type: 'sync';
    run: void;
    all: T['all'];
    get: T['get'];
    values: T['values'];
}> {
    private stmt;
    private queryString;
    private params;
    private logger;
    private fields;
    constructor(stmt: Statement, queryString: string, params: unknown[], logger: Logger, fields: SelectFieldsOrdered | undefined);
    run(placeholderValues?: Record<string, unknown>): void;
    all(placeholderValues?: Record<string, unknown>): T['all'];
    get(placeholderValues?: Record<string, unknown>): T['get'];
    values(placeholderValues?: Record<string, unknown>): T['values'];
}
export {};
